@@ -395,8 +395,10 @@ Q_SIGNALS:
      * to the terminal.
      * @p shape cursor shape
      * @p isBlinking if true, the cursor will be set to blink
+     * @p customColor custom cursor color
      */
-    void setCursorStyleRequest(Enum::CursorShapeEnum shape = Enum::BlockCursor, bool isBlinking = false);
+    void setCursorStyleRequest(Enum::CursorShapeEnum shape = Enum::BlockCursor, bool isBlinking = false, const QColor &customColor = {});
+
     /**
      * Emitted when reset() is called to reset the cursor style to the
      * current profile cursor shape and blinking settings.
