@@ -27,6 +27,7 @@
 // Qt
 #include <QDir>
 #include <QFileInfo>
+#include <QtGlobal>
 #include <QHostInfo>
 #include <QStringList>
 #include <QTextStream>
@@ -152,7 +153,7 @@ QString ProcessInfo::formatShortDir(const QString &input) const
     for (auto it = parts.crbegin(), endIt = parts.crend(); it != endIt; ++it) {
         const QString &part = *it;
         if (dirNamesToShorten.contains(part)) {
-            result.prepend(QDir::separator() + part[0]);
+            result.prepend(QDir::separator() + static_cast<QString>(part[0]));
         } else {
             result.prepend(part);
             break;
@@ -418,7 +419,7 @@ private:
             int field = 0;
             int pos = 0;
 
-            while (pos < data.count()) {
+            while (pos < data.length()) {
                 QChar c = data[pos];
 
                 if (c == QLatin1Char('(')) {
@@ -820,13 +821,89 @@ private:
             }
             setPid(pid);
         }
+
+        // Get user id - this will allow using username
+        struct proc_bsdshortinfo bsdinfo;
+        int ret;
+        bool ok = false;
+        const int fpid = foregroundPid(&ok);
+        if (ok) {
+            ret = proc_pidinfo(fpid, PROC_PIDT_SHORTBSDINFO, 0,
+                               &bsdinfo, sizeof(bsdinfo));
+            if (ret == sizeof(bsdinfo)) {
+                setUserId(bsdinfo.pbsi_uid);
+            }
+            // This will cause constant opening of /etc/passwd
+            if (userNameRequired()) {
+                readUserName();
+                setUserNameRequired(false);
+            }
+        }
+
         return true;
     }
 
     bool readArguments(int pid) override
     {
-        Q_UNUSED(pid)
-        return false;
+        int managementInfoBase[3];
+        size_t size;
+        std::string procargs;
+
+        managementInfoBase[0] = CTL_KERN;
+        managementInfoBase[1] = KERN_PROCARGS2;
+        managementInfoBase[2] = pid;
+
+        // It is not clear on why this fails for some commands
+        if (sysctl(managementInfoBase, 3, nullptr, &size, nullptr, 0) == -1) {
+            qWarning()<<"OS_MACOS: unable to obtain argument size for "<<pid;
+            return false;
+        }
+
+        // Some macosx versions need extra space
+        const size_t argmax = size + 32;
+        procargs.resize(argmax);
+
+        if (sysctl(managementInfoBase, 3, &procargs[0], &size, nullptr, 0) == -1) {
+            qWarning()<<"OS_MACOS: unable to obtain arguments for "<<pid;
+            return false;
+        } else {
+            auto args = QString::fromStdString(procargs);
+            auto parts = args.split(QLatin1Char('\u0000'), Qt::SkipEmptyParts);
+            // Do a lot of data checks
+            if (parts.isEmpty()) {
+                return false;
+            }
+            /*  0: argc as \u####
+                1: full command path
+                2: command (no path)
+                3: first argument
+                4+: next arguments
+                argc+: a lot of other data including ENV
+            */
+            auto argcs = parts[0]; // first string argc
+            if (argcs.isEmpty()) {
+                return false;
+            }
+            auto argc = (int)QChar(argcs[0]).unicode();
+            if (argc < 1) { // trash
+                return false;
+            } else if (argc == 1) { // just command, no args
+                addArgument(parts[1]); // this is the full path + command
+                return true;
+            }
+
+            // Check argc + 2(argc/full cmd) is not larger then parts size
+            argc = qMin(argc + 2, parts.size());
+
+            /* The output is not obvious for some commands:
+               For example: 'man 3 sysctl' shows arg=4
+               0: \u0004; 1: /bin/bash; 2: /bin/sh; 3: /usr/bin/man; 4: 3; 5: sysctl
+             */
+            for (int i = 2; i < argc; i++) {
+                addArgument(parts[i]);
+            }
+            return true;
+        }
     }
 };
 
