@@ -17,6 +17,7 @@
 
 // System
 #include <csignal>
+#include <errno.h>
 #include <sys/ioctl.h> //ioctl() and TIOCSWINSZ
 #include <termios.h>
 
@@ -97,7 +98,7 @@ void Pty::dataReceived()
         return;
     }
 
-    Q_EMIT receivedData(data.constData(), data.count());
+    Q_EMIT receivedData(data.constData(), data.length());
 }
 
 void Pty::setWindowSize(int columns, int lines, int width, int height)
@@ -318,8 +319,12 @@ int Pty::foregroundProcessGroup() const
 
         if (foregroundPid != -1) {
             return foregroundPid;
+        } else {
+            qCWarning(KonsoleDebug, "Failed to get foreground process group id for %d: %s", master_fd, strerror(errno));
+            return 0;
         }
     }
+    qWarning(KonsoleDebug, "foregroundProcessGroup master_fd < 0");
 
     return 0;
 }
