@@ -9,14 +9,21 @@
 #define PTY_H
 
 // Qt
+#include <QProcess>
 #include <QSize>
 
-// KDE
-#include <KPtyProcess>
-
 // Konsole
 #include "konsoleprivate_export.h"
 
+#ifndef Q_OS_WIN
+// KDE
+#include <KPtyProcess>
+#else
+#include <QObject>
+
+#include "ptyqt/iptyprocess.h"
+#endif
+
 namespace Konsole
 {
 /**
@@ -32,7 +39,15 @@ namespace Konsole
  * To start the terminal process, call the start() method
  * with the program name and appropriate arguments.
  */
-class KONSOLEPRIVATE_EXPORT Pty : public KPtyProcess
+#ifdef Q_OS_WIN
+#define _k_override_
+#define ParentClass QObject
+#else
+#define _k_override_ override
+#define ParentClass KPtyProcess
+#endif
+
+class KONSOLEPRIVATE_EXPORT Pty : public ParentClass
 {
     Q_OBJECT
 
@@ -56,6 +71,7 @@ public:
 
     ~Pty() override;
 
+#ifndef Q_OS_WIN
     /**
      * Starts the terminal process.
      *
@@ -69,6 +85,22 @@ public:
      * should include an assignment for the TERM environment variable.
      */
     int start(const QString &program, const QStringList &arguments, const QStringList &environment);
+#else
+    /**
+     * Starts the terminal process.
+     *
+     * Returns 0 if the process was started successfully or non-zero
+     * otherwise.
+     *
+     * @param program Path to the program to start
+     * @param arguments Arguments to pass to the program being started
+     * @param workingDir initial working directory
+     * @param environment A list of key=value pairs which will be added
+     * to the environment for the new process.  At the very least this
+     * should include an assignment for the TERM environment variable.
+     */
+    int start(const QString &program, const QStringList &arguments, const QString &workingDir, const QStringList &environment, int cols, int lines);
+#endif
 
     /** Control whether the pty device is writeable by group members. */
     void setWriteable(bool writeable);
@@ -124,6 +156,47 @@ public:
      */
     void closePty();
 
+#ifdef Q_OS_WIN
+    int processId() const
+    {
+        if (m_proc && m_proc->isAvailable()) {
+            return m_proc->pid();
+        }
+        return 0;
+    }
+
+    bool isRunning() const
+    {
+        return processId() > 0;
+    }
+
+    QString errorString() const
+    {
+        if (m_proc) {
+            return m_proc->lastError();
+        }
+        return QStringLiteral("Conhost failed to start");
+    }
+
+    bool kill()
+    {
+        if (m_proc) {
+            return m_proc->kill();
+        }
+        return false;
+    }
+
+    int exitCode() const
+    {
+        if (m_proc) {
+            return m_proc->exitCode();
+        }
+        return -1;
+    }
+
+    Q_SIGNAL void finished(int exitCode, QProcess::ExitStatus);
+#endif
+
 public Q_SLOTS:
     /**
      * Put the pty into UTF-8 mode on systems which support it.
@@ -151,9 +224,11 @@ Q_SIGNALS:
 protected:
     // TODO: remove this; the method is removed from QProcess in Qt6
     // instead use setChildProcessModifier() in the constructor
+#ifndef Q_OS_WIN
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    void setupChildProcess() override;
-#endif
+    void setupChildProcess() _k_override_;
+#endif // QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#endif // Q_OS_WIN
 
 private Q_SLOTS:
     // called when data is received from the terminal process
@@ -173,7 +248,12 @@ private:
     char _eraseChar;
     bool _xonXoff;
     bool _utf8;
+#ifdef Q_OS_WIN
+    std::unique_ptr<IPtyProcess> m_proc;
+#endif
 };
 }
 
+#undef ParentClass
+
 #endif // PTY_H
