@@ -11,6 +11,7 @@
 // Qt
 #include <QHash>
 #include <QMap>
+#include <QMediaPlayer>
 #include <QPair>
 #include <QVector>
 
@@ -97,6 +98,7 @@ private Q_SLOTS:
     // pair in _pendingSessionAttributesUpdates.
     // Used to buffer multiple attribute updates in the current session
     void updateSessionAttributes();
+    void deletePlayer(QMediaPlayer::MediaStatus);
 
 private:
     unsigned int applyCharset(uint c);
@@ -176,6 +178,17 @@ private:
         Apc,
     } _sosPmApc;
 
+    enum osc {
+        // https://invisible-island.net/xterm/ctlseqs/ctlseqs.html#h2-Operating-System-Commands
+        ReportColors = 4,
+        ResetColors = 104,
+        // https://gitlab.freedesktop.org/Per_Bothner/specifications/blob/master/proposals/semantic-prompts.md
+        SemanticPrompts = 133,
+        // https://chromium.googlesource.com/apps/libapps/+/master/hterm/doc/ControlSequences.md#OSC
+        Notification = 777,
+        Image = 1337,
+    };
+
     ParserStates _state = Ground;
     bool _ignore = false;
     int _nIntermediate = 0;
@@ -299,6 +312,8 @@ private:
     QHash<int, QPixmap> _graphicsImages;
     // For kitty graphics protocol - image cache
     int getFreeGraphicsImageId();
+
+    QMediaPlayer *player;
 };
 
 }
