@@ -15,10 +15,10 @@
 
 using Konsole::ZModemDialog;
 
-ZModemDialog::ZModemDialog(QWidget *aParent, bool modal, const QString &caption) :
-    QDialog(aParent),
-    _textEdit(nullptr),
-    mButtonBox(nullptr)
+ZModemDialog::ZModemDialog(QWidget *aParent, bool modal, const QString &caption)
+    : QDialog(aParent)
+    , _textEdit(nullptr)
+    , mButtonBox(nullptr)
 {
     setObjectName(QStringLiteral("zmodem_progress"));
     setModal(modal);
