@@ -11,7 +11,7 @@
 #include "keyboardtranslator/KeyboardTranslatorReader.h"
 
 // KDE
-#include <qtest.h>
+#include <QTest>
 
 using namespace Konsole;
 
