@@ -1,21 +1,8 @@
 /*
-    Copyright 2008 by Robert Knight <robertknight@gmail.com>
-    Copyright 2013 by Kurt Hindenburg <kurt.hindenburg@gmail.com>
+    SPDX-FileCopyrightText: 2008 Robert Knight <robertknight@gmail.com>
+    SPDX-FileCopyrightText: 2013 Kurt Hindenburg <kurt.hindenburg@gmail.com>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301  USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // Own
@@ -25,7 +12,7 @@
 #include <QStringList>
 
 // KDE
-#include <qtest.h>
+#include <QTest>
 
 using namespace Konsole;
 
@@ -54,7 +41,7 @@ void ShellCommandTest::testConstructorWithTwoArguments()
     ShellCommand shellCommand(command, arguments);
     QCOMPARE(shellCommand.command(), command);
     QCOMPARE(shellCommand.arguments(), arguments);
-    QCOMPARE(shellCommand.fullCommand(), arguments.join(QLatin1Char(' ')));
+    QCOMPARE(shellCommand.fullCommand(), arguments.join(QLatin1String(" ")));
 }
 
 void ShellCommandTest::testExpandEnvironmentVariable()
