@@ -6,7 +6,7 @@
 
 // To time the creation and total launch time (i. e. until window is
 // visible/responsive):
-//#define PROFILE_STARTUP
+// #define PROFILE_STARTUP
 
 // Own
 #include "Application.h"
@@ -134,6 +134,16 @@ int main(int argc, char *argv[])
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
 #endif
+
+    /**
+     * enable dark mode for title bar on Windows
+     */
+#if defined(Q_OS_WIN)
+    if (!qEnvironmentVariableIsSet("QT_QPA_PLATFORM")) {
+        qputenv("QT_QPA_PLATFORM", "windows:darkmode=1");
+    }
+#endif
+
     // Check if any of the arguments makes it impossible to re-use an existing process.
     // We need to do this manually and before creating a QApplication, because
     // QApplication takes/removes the Qt specific arguments that are incompatible.
@@ -143,7 +153,16 @@ int main(int argc, char *argv[])
     }
 
     auto app = new QApplication(argc, argv);
+    /**
+     * For Windows: use Breeze if available
+     * Of all tested styles that works the best for us
+     * NOTE: Taken from Kate
+     */
+#if defined(Q_OS_WIN)
+    QApplication::setStyle(QStringLiteral("breeze"));
+#else
     app->setStyle(new MenuStyle());
+#endif
 
     migrateRenamedConfigKeys();
 
