@@ -11,6 +11,7 @@
 #include "Profile.h"
 
 // Qt
+#include <QDir>
 #include <QFileInfo>
 #include <QTextCodec>
 
@@ -24,11 +25,13 @@
 #include "ProfileGroup.h"
 #include "config-konsole.h"
 
+#ifndef Q_OS_WIN
 #ifdef HAVE_GETPWUID
 #include <pwd.h>
 #include <sys/types.h>
 #include <unistd.h>
-#endif
+#endif // HAVE_GETPWUID
+#endif // Q_OS_WIN
 
 #if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 97, 0)
 #include <KSandbox>
@@ -36,6 +39,12 @@
 
 using namespace Konsole;
 
+#if defined(Q_OS_WIN)
+#define DEFAULT_ENCODING QStringLiteral("utf8")
+#else
+#define DEFAULT_ENCODING QString()
+#endif
+
 // mappings between property enum values and names
 //
 // multiple names are defined for some property values,
@@ -99,6 +108,7 @@ const std::vector<Profile::PropertyInfo> Profile::DefaultProperties = {
     {WordModeAttr, "WordModeAttr", APPEARANCE_GROUP, false},
     {WordModeAscii, "WordModeAscii", APPEARANCE_GROUP, true},
     {WordModeBrahmic, "WordModeBrahmic", APPEARANCE_GROUP, false},
+    {IgnoreWcWidth, "IgnoreWcWidth", APPEARANCE_GROUP, false},
 
 // Keyboard
 #ifdef Q_OS_MACOS
@@ -161,7 +171,7 @@ const std::vector<Profile::PropertyInfo> Profile::DefaultProperties = {
     {ColorFilterEnabled, "ColorFilterEnabled", INTERACTION_GROUP, true},
 
     // Encoding
-    {DefaultEncoding, "DefaultEncoding", ENCODING_GROUP, QString()},
+    {DefaultEncoding, "DefaultEncoding", ENCODING_GROUP, DEFAULT_ENCODING},
 };
 
 QHash<QString, Profile::PropertyInfo> Profile::PropertyInfoByName;
@@ -176,8 +186,38 @@ static const QString BUILTIN_MAGIC_PATH = QStringLiteral("FALLBACK/");
 // Note: regular profiles created in earlier versions of Konsole may have this name too.
 static const char BUILTIN_UNTRANSLATED_NAME_CHAR[] = "Built-in";
 
+#ifdef Q_OS_WIN
+static QString checkFile(const QStringList &dirList, const QString &filePath)
+{
+    for (const QString &root : dirList) {
+        QFileInfo info(root, filePath);
+        if (info.exists()) {
+            return QDir::toNativeSeparators(info.filePath());
+        }
+    }
+    return QString();
+}
+
+static QString GetWindowPowerShell()
+{
+    QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
+    QStringList dirList;
+    dirList << env.value(QStringLiteral("windir"), QStringLiteral("C:\\Windows"));
+    return checkFile(dirList, QStringLiteral("System32\\WindowsPowerShell\\v1.0\\powershell.exe"));
+}
+
+static QString GetWindowsShell()
+{
+    QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
+    QString windir = env.value(QStringLiteral("windir"), QStringLiteral("C:\\Windows"));
+    QFileInfo info(windir, QStringLiteral("System32\\cmd.exe"));
+    return QDir::toNativeSeparators(info.filePath());
+}
+#endif
+
 static QString defaultShell()
 {
+#ifndef Q_OS_WIN
 #if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 97, 0)
     if (!KSandbox::isFlatpak()) {
         return QString::fromUtf8(qgetenv("SHELL"));
@@ -202,6 +242,14 @@ static QString defaultShell()
 #else
     return QString::fromUtf8(qgetenv("SHELL"));
 #endif
+
+#else // Q_OS_WIN
+    auto shell = GetWindowPowerShell();
+    if (shell.isEmpty()) {
+        shell = GetWindowsShell();
+    }
+    return shell;
+#endif // Q_OS_WIN
 }
 
 void Profile::fillTableWithDefaultNames()
@@ -229,7 +277,11 @@ void Profile::useBuiltin()
     // See Pty.cpp on why Arguments is populated
     setProperty(Arguments, QStringList{defaultShell()});
     setProperty(Font, QFontDatabase::systemFont(QFontDatabase::FixedFont));
+#if defined(Q_OS_WIN)
+    setProperty(DefaultEncoding, QLatin1String(QTextCodec::codecForName("utf8")->name()));
+#else
     setProperty(DefaultEncoding, QLatin1String(QTextCodec::codecForLocale()->name()));
+#endif
     // Built-in profile should not be shown in menus
     setHidden(true);
 }
