@@ -13,12 +13,11 @@
 
 namespace Konsole
 {
-
 SessionDisplayConnection::SessionDisplayConnection(Session *session, TerminalDisplay *view, QObject *parent)
     : QObject(parent)
+    , _session(session)
+    , _view(view)
 {
-    _session = session;
-    _view = view;
 }
 
 QPointer<Session> SessionDisplayConnection::session()
@@ -36,4 +35,4 @@ bool SessionDisplayConnection::isValid() const
     return !_session.isNull() && !_view.isNull();
 }
 
-}   // namespace Konsole
+} // namespace Konsole
