@@ -9,8 +9,6 @@
 // Own
 #include "SessionManager.h"
 
-#include "konsoledebug.h"
-
 // Qt
 #include <QStringList>
 #include <QTextCodec>
@@ -25,6 +23,7 @@
 #include "EscapeSequenceUrlExtractor.h"
 #include "Screen.h"
 #include "ShouldApplyProperty.h"
+#include "konsoledebug.h"
 
 #include "history/HistoryTypeFile.h"
 #include "history/HistoryTypeNone.h"
@@ -202,7 +201,10 @@ void SessionManager::applyProfile(Session *session, const Profile::Ptr &profile,
         QStringList environment = profile->environment();
         environment << QStringLiteral("PROFILEHOME=%1").arg(profile->defaultWorkingDirectory());
         environment << QStringLiteral("KONSOLE_VERSION=%1").arg(numericVersion);
-
+#ifdef Q_OS_WIN
+        // Needed on windows otherwise powershell will refuse to start
+        environment += QProcess::systemEnvironment();
+#endif
         session->setEnvironment(environment);
     }
 
@@ -273,11 +275,13 @@ void SessionManager::applyProfile(Session *session, const Profile::Ptr &profile,
     if (apply.shouldApply(Profile::SilenceSeconds)) {
         session->setMonitorSilenceSeconds(profile->silenceSeconds());
     }
-    if (apply.shouldApply(Profile::AllowEscapedLinks) || apply.shouldApply(Profile::ReflowLines)) {
+    if (apply.shouldApply(Profile::AllowEscapedLinks) || apply.shouldApply(Profile::ReflowLines) || apply.shouldApply(Profile::IgnoreWcWidth)) {
         const bool shouldEnableUrlExtractor = profile->allowEscapedLinks();
         const bool enableReflowLines = profile->property<bool>(Profile::ReflowLines);
+        const bool ignoreWcWidth = profile->property<bool>(Profile::IgnoreWcWidth);
         for (TerminalDisplay *view : session->views()) {
             view->screenWindow()->screen()->setReflowLines(enableReflowLines);
+            view->screenWindow()->screen()->setIgnoreWcWidth(ignoreWcWidth);
             view->screenWindow()->screen()->setEnableUrlExtractor(shouldEnableUrlExtractor);
             if (shouldEnableUrlExtractor) {
                 view->screenWindow()->screen()->urlExtractor()->setAllowedLinkSchema(profile->escapedLinksSchema());
