@@ -16,22 +16,16 @@
 #include "session/SessionController.h"
 
 // KDE
-#include <KMessageWidget>
 
 // Qt
 #include <QGuiApplication>
-#include <QLabel>
 #include <QProxyStyle>
 #include <QRect>
-#include <QTimer>
 
 namespace Konsole
 {
 TerminalScrollBar::TerminalScrollBar(QWidget *parent)
     : QScrollBar(parent)
-    , _scrollFullPage(false)
-    , _alternateScrolling(false)
-    , _scrollbarLocation(Enum::ScrollBarRight)
 {
     connect(this, &QScrollBar::valueChanged, this, &TerminalScrollBar::scrollBarPositionChanged);
 }
@@ -80,7 +74,6 @@ void TerminalScrollBar::setHighlightScrolledLines(bool highlight)
 {
     _highlightScrolledLines.setEnabled(highlight);
     _highlightScrolledLines.setTimer(this);
-    _highlightScrolledLines.setNeedToClear(true);
 }
 
 bool TerminalScrollBar::alternateScrolling() const
