@@ -20,8 +20,8 @@
 // KDE
 #include <KMainWindow>
 #include <KPluginFactory>
+#include <QTest>
 #include <kservice_version.h>
-#include <qtest.h>
 
 #if KSERVICE_VERSION < QT_VERSION_CHECK(5, 86, 0)
 #include <KPluginLoader>
@@ -67,7 +67,7 @@ void PartManualTest::testShortcutOverride()
     _shortcutTriggered = false;
     _override = false;
     _overrideCalled = false;
-    QVERIFY(connect(terminalPart, SIGNAL(overrideShortcut(QKeyEvent *, bool &)), this, SLOT(overrideShortcut(QKeyEvent *, bool &))));
+    QVERIFY(connect(terminalPart, SIGNAL(overrideShortcut(QKeyEvent*,bool&)), this, SLOT(overrideShortcut(QKeyEvent*,bool&))));
 
     // QTest::keyClick(terminalPart->widget(),Qt::Key_S,Qt::ControlModifier);
     _shortcutEventLoop = new QEventLoop();
