@@ -8,22 +8,22 @@
 #include "KonsoleSettings.h"
 #include "widgets/ViewContainer.h"
 
-#include <QMouseEvent>
 #include <QApplication>
 #include <QMimeData>
+#include <QMouseEvent>
 
 #include <KAcceleratorManager>
 
-#include <QPainter>
 #include <QColor>
+#include <QPainter>
 
-namespace Konsole {
-
-DetachableTabBar::DetachableTabBar(QWidget *parent) :
-    QTabBar(parent),
-    dragType(DragType::NONE),
-    _originalCursor(cursor()),
-    tabId(-1)
+namespace Konsole
+{
+DetachableTabBar::DetachableTabBar(QWidget *parent)
+    : QTabBar(parent)
+    , dragType(DragType::NONE)
+    , _originalCursor(cursor())
+    , tabId(-1)
 {
     setAcceptDrops(true);
     setElideMode(Qt::TextElideMode::ElideLeft);
@@ -40,7 +40,7 @@ void DetachableTabBar::removeColor(int idx)
     setTabData(idx, QVariant());
 }
 
-void DetachableTabBar::middleMouseButtonClickAt(const QPoint& pos)
+void DetachableTabBar::middleMouseButtonClickAt(const QPoint &pos)
 {
     tabId = tabAt(pos);
 
@@ -52,7 +52,7 @@ void DetachableTabBar::middleMouseButtonClickAt(const QPoint& pos)
 void DetachableTabBar::mousePressEvent(QMouseEvent *event)
 {
     QTabBar::mousePressEvent(event);
-    _containers = window()->findChildren<Konsole::TabbedViewContainer*>();
+    _containers = window()->findChildren<Konsole::TabbedViewContainer *>();
 }
 
 void DetachableTabBar::mouseMoveEvent(QMouseEvent *event)
@@ -71,7 +71,7 @@ void DetachableTabBar::mouseMoveEvent(QMouseEvent *event)
                 setCursor(QCursor(Qt::DragMoveCursor));
             }
         }
-    } else if (!contentsRect().adjusted(-30,-30,30,30).contains(event->pos())) {
+    } else if (!contentsRect().adjusted(-30, -30, 30, 30).contains(event->pos())) {
         // Don't let it detach the last tab.
         if (count() == 1) {
             return;
@@ -87,23 +87,27 @@ void DetachableTabBar::mouseReleaseEvent(QMouseEvent *event)
 {
     QTabBar::mouseReleaseEvent(event);
 
-    switch(event->button()) {
-        case Qt::MiddleButton : if (KonsoleSettings::closeTabOnMiddleMouseButton()) {
-                                    middleMouseButtonClickAt(event->pos());
-                                }
+    switch (event->button()) {
+    case Qt::MiddleButton:
+        if (KonsoleSettings::closeTabOnMiddleMouseButton()) {
+            middleMouseButtonClickAt(event->pos());
+        }
 
-                                tabId = tabAt(event->pos());
-                                if (tabId == -1) {
-                                    Q_EMIT newTabRequest();
-                                }
-                                break;
-        case Qt::LeftButton: _containers = window()->findChildren<Konsole::TabbedViewContainer*>(); break;
-        default: break;
+        tabId = tabAt(event->pos());
+        if (tabId == -1) {
+            Q_EMIT newTabRequest();
+        }
+        break;
+    case Qt::LeftButton:
+        _containers = window()->findChildren<Konsole::TabbedViewContainer *>();
+        break;
+    default:
+        break;
     }
 
     setCursor(_originalCursor);
 
-    if (contentsRect().adjusted(-30,-30,30,30).contains(event->pos())) {
+    if (contentsRect().adjusted(-30, -30, 30, 30).contains(event->pos())) {
         return;
     }
 
@@ -119,7 +123,7 @@ void DetachableTabBar::mouseReleaseEvent(QMouseEvent *event)
     }
 }
 
-void DetachableTabBar::dragEnterEvent(QDragEnterEvent* event)
+void DetachableTabBar::dragEnterEvent(QDragEnterEvent *event)
 {
     const auto dragId = QStringLiteral("konsole/terminal_display");
     if (!event->mimeData()->hasFormat(dragId)) {
@@ -133,7 +137,7 @@ void DetachableTabBar::dragEnterEvent(QDragEnterEvent* event)
     event->accept();
 }
 
-void DetachableTabBar::dragMoveEvent(QDragMoveEvent* event)
+void DetachableTabBar::dragMoveEvent(QDragMoveEvent *event)
 {
     int tabIdx = tabAt(event->pos());
     if (tabIdx != -1) {
@@ -145,7 +149,7 @@ void DetachableTabBar::paintEvent(QPaintEvent *event)
 {
     QTabBar::paintEvent(event);
     if (!event->isAccepted()) {
-        return;       // Reduces repainting
+        return; // Reduces repainting
     }
 
     QPainter painter(this);
@@ -164,7 +168,7 @@ void DetachableTabBar::paintEvent(QPaintEvent *event)
 
         painter.setBrush(varColor);
         QRect tRect = tabRect(tabIndex);
-        tRect.setTop(painter.fontMetrics().height() + 6);   // Color bar top position consider a height the font and fixed spacing of 6px
+        tRect.setTop(painter.fontMetrics().height() + 6); // Color bar top position consider a height the font and fixed spacing of 6px
         tRect.setHeight(4);
         tRect.setLeft(tRect.left() + 6);
         tRect.setWidth(tRect.width() - 6);
